@@ -70,7 +70,7 @@ addCallback("historyrunner", "find", (message) => {
                     chrome.tabs.query({
                         url: result.url
                     }, (tabs) => {
-                        if (!tabs || chrome.runtime.lastError) {
+                        if (chrome.runtime.lastError || !tabs) {
                             return resolve([]);
                         }
 
@@ -146,6 +146,6 @@ addCallback("historyrunner", "run", (message) => {
 
 addCallback("historyrunner", "requestPermission", () => {
     chrome.tabs.create({
-        url: chrome.extension.getURL("permission_request.html") + "?permission=history"
+        url: chrome.runtime.getURL("permission_request.html") + "?permission=history"
     });
 });
