@@ -11,7 +11,7 @@ struct RemoteMatch {
     QString id;
     QString text;
     QString iconName;
-    Plasma::QueryMatch::Type type = Plasma::QueryMatch::NoMatch;
+    KRunner::QueryMatch::Type type = KRunner::QueryMatch::NoMatch;
     qreal relevance = 0;
     QVariantMap properties;
 };
@@ -58,7 +58,7 @@ inline const QDBusArgument &operator>>(const QDBusArgument &argument, RemoteMatc
     argument >> match.iconName;
     uint type;
     argument >> type;
-    match.type = static_cast<Plasma::QueryMatch::Type>(type);
+    match.type = static_cast<KRunner::QueryMatch::Type>(type);
     argument >> match.relevance;
     argument >> match.properties;
     argument.endStructure();
