@@ -49,6 +49,7 @@ BrowserIntegrationReminder::BrowserIntegrationReminder(QObject *parent, const QL
     QUrl firefox(QStringLiteral("https://addons.mozilla.org/en-US/firefox/addon/plasma-integration/"));
     m_browsers[QStringLiteral("firefox.desktop")] = firefox;
     m_browsers[QStringLiteral("nightly.desktop")] = firefox;
+    m_browsers[QStringLiteral("librewolf.desktop")] = firefox;
 
     QUrl chrome(QStringLiteral("https://chrome.google.com/webstore/detail/plasma-integration/cimiefiiaegbelhefglklhhakcgmhkai"));
     m_browsers[QStringLiteral("google-chrome.desktop")] = chrome;
@@ -178,9 +179,9 @@ void BrowserIntegrationReminder::onBrowserStarted(const QString &browser)
 void BrowserIntegrationReminder::unload()
 {
     QDBusConnection dbus = QDBusConnection::sessionBus();
-    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded5"),
+    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded6"),
                                                       QStringLiteral("/kded"),
-                                                      QStringLiteral("org.kde.kded5"),
+                                                      QStringLiteral("org.kde.kded6"),
                                                       QStringLiteral("unloadModule"));
     msg.setArguments({QVariant(QStringLiteral("browserintegrationreminder"))});
     dbus.call(msg, QDBus::NoBlock);
@@ -189,9 +190,9 @@ void BrowserIntegrationReminder::unload()
 void BrowserIntegrationReminder::disableAutoload()
 {
     QDBusConnection dbus = QDBusConnection::sessionBus();
-    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded5"),
+    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded6"),
                                                       QStringLiteral("/kded"),
-                                                      QStringLiteral("org.kde.kded5"),
+                                                      QStringLiteral("org.kde.kded6"),
                                                       QStringLiteral("setModuleAutoloading"));
     msg.setArguments({QVariant(QStringLiteral("browserintegrationreminder")), QVariant(false)});
     dbus.call(msg, QDBus::NoBlock);
@@ -199,3 +200,5 @@ void BrowserIntegrationReminder::disableAutoload()
 }
 
 #include "browserintegrationreminder.moc"
+
+#include "moc_browserintegrationreminder.cpp"
